@@ -1,8 +1,9 @@
-# -*- coding: utf-8 -*-
+# -*- coding: future_annotations -*-
 import copy
 from datetime import timedelta
 import logging
 import os
+from typing import cast, Any, Dict, Iterator, List, Optional
 
 import pysubs2
 import srt
@@ -13,22 +14,24 @@ logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 
 
-class SubsMixin(object):
-    def __init__(self, subs=None):
-        self.subs_ = subs
+class SubsMixin:
+    def __init__(self, subs: Optional[GenericSubtitlesFile] = None) -> None:
+        self.subs_: Optional[GenericSubtitlesFile] = subs
 
-    def set_encoding(self, encoding):
+    def set_encoding(self, encoding: str) -> SubsMixin:
         self.subs_.set_encoding(encoding)
         return self
 
 
-class GenericSubtitle(object):
+class GenericSubtitle:
     def __init__(self, start, end, inner):
         self.start = start
         self.end = end
         self.inner = inner
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, GenericSubtitle):
+            return False
         eq = True
         eq = eq and self.start == other.start
         eq = eq and self.end == other.end
@@ -36,7 +39,7 @@ class GenericSubtitle(object):
         return eq
 
     @property
-    def content(self):
+    def content(self) -> str:
         if isinstance(self.inner, srt.Subtitle):
             ret = self.inner.content
         elif isinstance(self.inner, pysubs2.SSAEvent):
@@ -71,7 +74,7 @@ class GenericSubtitle(object):
             raise NotImplementedError('unsupported subtitle type: %s' % type(self.inner))
 
     @classmethod
-    def wrap_inner_subtitle(cls, sub):
+    def wrap_inner_subtitle(cls, sub) -> GenericSubtitle:
         if isinstance(sub, srt.Subtitle):
             return cls(sub.start, sub.end, sub)
         elif isinstance(sub, pysubs2.SSAEvent):
@@ -84,66 +87,58 @@ class GenericSubtitle(object):
             raise NotImplementedError('unsupported subtitle type: %s' % type(sub))
 
 
-class GenericSubtitlesFile(object):
-    def __init__(self, subs, *args, **kwargs):
-        sub_format = kwargs.pop('sub_format', None)
+class GenericSubtitlesFile:
+    def __init__(self, subs: List[GenericSubtitle], *_, **kwargs: Any):
+        sub_format: str = cast(str, kwargs.pop('sub_format', None))
         if sub_format is None:
             raise ValueError('format must be specified')
-        encoding = kwargs.pop('encoding', None)
+        encoding: str = cast(str, kwargs.pop('encoding', None))
         if encoding is None:
             raise ValueError('encoding must be specified')
-        self.subs_ = subs
-        self._sub_format = sub_format
-        self._encoding = encoding
-        self._styles = kwargs.pop('styles', None)
-        self._info = kwargs.pop('info', None)
+        self.subs_: List[GenericSubtitle] = subs
+        self._sub_format: str = sub_format
+        self._encoding: str = encoding
+        self._styles: Optional[Dict[str, pysubs2.SSAStyle]] = kwargs.pop('styles', None)
+        self._fonts_opaque: Optional[Dict[str, Any]] = kwargs.pop('fonts_opaque', None)
+        self._info: Optional[Dict[str, str]] = kwargs.pop('info', None)
 
-    def set_encoding(self, encoding):
+    def set_encoding(self, encoding: str) -> GenericSubtitlesFile:
         if encoding != 'same':
             self._encoding = encoding
         return self
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self.subs_)
 
-    def __getitem__(self, item):
+    def __getitem__(self, item: int) -> GenericSubtitle:
         return self.subs_[item]
 
-    @property
-    def sub_format(self):
-        return self._sub_format
+    def __iter__(self) -> Iterator[GenericSubtitle]:
+        return iter(self.subs_)
 
-    @property
-    def encoding(self):
-        return self._encoding
-
-    @property
-    def styles(self):
-        return self._styles
-
-    @property
-    def info(self):
-        return self._info
+    def clone_props_for_subs(self, new_subs: List[GenericSubtitle]) -> GenericSubtitlesFile:
+        return GenericSubtitlesFile(
+            new_subs,
+            sub_format=self._sub_format,
+            encoding=self._encoding,
+            styles=self._styles,
+            fonts_opaque=self._fonts_opaque,
+            info=self._info,
+        )
 
     def gen_raw_resolved_subs(self):
         for sub in self.subs_:
             yield sub.resolve_inner_timestamps()
 
-    def offset(self, td):
+    def offset(self, td: timedelta) -> GenericSubtitlesFile:
         offset_subs = []
         for sub in self.subs_:
             offset_subs.append(
                 GenericSubtitle(sub.start + td, sub.end + td, sub.inner)
             )
-        return GenericSubtitlesFile(
-            offset_subs,
-            sub_format=self.sub_format,
-            encoding=self.encoding,
-            styles=self.styles,
-            info=self.info
-        )
+        return self.clone_props_for_subs(offset_subs)
 
-    def write_file(self, fname):
+    def write_file(self, fname: str) -> None:
         # TODO: converter to go between self.subs_format and out_format
         if fname is None:
             out_format = self._sub_format
@@ -153,9 +148,12 @@ class GenericSubtitlesFile(object):
         if self._sub_format in ('ssa', 'ass'):
             ssaf = pysubs2.SSAFile()
             ssaf.events = subs
-            ssaf.styles = self.styles
-            if self.info is not None:
-                ssaf.info = self.info
+            if self._styles is not None:
+                ssaf.styles = self._styles
+            if self._info is not None:
+                ssaf.info = self._info
+            if self._fonts_opaque is not None:
+                ssaf.fonts_opaque = self._fonts_opaque
             to_write = ssaf.to_string(out_format)
         elif self._sub_format == 'srt' and out_format in ('ssa', 'ass'):
             to_write = pysubs2.SSAFile.from_string(srt.compose(subs)).to_string(out_format)
@@ -164,7 +162,7 @@ class GenericSubtitlesFile(object):
         else:
             raise NotImplementedError('unsupported output format: %s' % out_format)
 
-        to_write = to_write.encode(self.encoding)
+        to_write = to_write.encode(self._encoding)
         if six.PY3:
             with open(fname or sys.stdout.fileno(), 'wb') as f:
                 f.write(to_write)
